@@ -5,10 +5,10 @@ from nav_dcat.fields import common_fields
 
 
 class DatapackageDocument(BaseModel):
-    id: str
     title: str
     description: str
-    uri: str
+    uri: Optional[str] = ""
+    id: Optional[str] = None
     modified: Optional[str] = None
     issued: Optional[str] = None
     periodicity: Optional[str] = ""
